<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gallery_Photo_Gallery
 * @subpackage Gallery_Photo_Gallery/public
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Gallery_Photo_Gallery_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gallery_Photo_Gallery_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gallery_Photo_Gallery_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style( 'gpg-fontawesome', '//cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gallery-photo-gallery-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'jquery.mosaic.min.css', plugin_dir_url( __FILE__ ) . 'css/jquery.mosaic.min.css?v=4', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gallery_Photo_Gallery_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gallery_Photo_Gallery_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script( 'jquery-effects-core' );
        wp_enqueue_script( 'jquery-ui-sortable' );
        wp_enqueue_media();
        wp_enqueue_script( 'imagelightbox.min.js', plugin_dir_url( __FILE__ ) . 'js/imagelightbox.min.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( 'jquery.mosaic.min.js', plugin_dir_url( __FILE__ ) . 'js/jquery.mosaic.min.js?v=4', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gallery-photo-gallery-public.js', array( 'jquery' ), $this->version, true );

	}

    public function ays_initialize_gallery_shortcode(){
        add_shortcode( 'gallery_p_gallery', array($this, 'ays_generate_gallery') );
    }

    public function ays_generate_gallery( $attr ){
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;

        $gallery = $this->ays_get_gallery_by_id($id);

        /*
         * Gallery global settings
         */
        $title = $gallery["title"];
        $description = $gallery["description"];
        $width= $gallery["width"];
        $height= $gallery["height"];
        $gallery_options = json_decode($gallery['options'],true);

        /*
         * Gallery image settings
         */
        $columns = 3;
        $view    = $gallery_options['view_type'];
        $images         = explode( "***", $gallery["images"]        );
        $image_titles   = explode( "***", $gallery["images_titles"] );
        $image_descs    = explode( "***", $gallery["images_descs"]  );
        $image_alts     = explode( "***", $gallery["images_alts"]   );
        $image_urls     = explode( "***", $gallery["images_urls"]   );

        $images_count = count($images);
        $column_width = 100 / $columns;
        $gallery_view = "<div class='ays_gallery_container' style='width: ".$width."px'>
                                <div class='ays_gallery_header'>
                                    <h2 class='ays_gallery_title'>" . wp_unslash($title) . "</h2>
                                    <h4 class='ays_gallery_description'>" . wp_unslash($description) . "</h4>
                                </div>";
        switch( $view ){
            case "mosaic":
                $mosaic_columns          = $images;
                $mosaic_columns_titles   = $image_titles;
                $mosaic_columns_descs    = $image_descs;
                $mosaic_columns_alts     = $image_alts;
                $mosaic_columns_urls     = $image_urls;
                
                $gallery_image_sizes = '';
                $gallery_view .= "<div id='mosaic' class='mosaic' style='clear:both;'>";

                foreach ($mosaic_columns as $key => $mosaic_column){
                    $gallery_image_sizes = getimagesize($mosaic_column);
                    $gallery_view .= "<div class='item withImage '   >";
                         $gallery_view .= "<a href='" . $mosaic_column . "' data-imagelightbox='f'>
                                                <img src='" . $mosaic_column . "' alt='" . wp_unslash($mosaic_columns_alts[$key]) . "' title='" . wp_unslash($mosaic_columns_titles[$key]) . "' 
                                                 data-description='" . wp_unslash($mosaic_columns_descs[$key]) . "' data-url='" . $mosaic_columns_urls[$key] . "'/>
                                                 <div class='ays_hover_mask'><i class='fa  fa-search-plus'></i></div>
                                            </a>                                            
                                      </div>";
                }
                $gallery_view .= "</div>
                                    <script>
                                        $(function() {
                                            $('#mosaic').Mosaic({
                                                innerGap: 20
                                            });
                                        });
                                    </script>";
                break;
            case "grid":
                $gallery_view .= "<div class='ays_grid_row'>";
                foreach ($images as $key => $image){
                    $gallery_view .="<div class='ays_grid_column' style='width: ".($column_width - 1)."%; background-image: url(".$image.")'>
                                            <a href='" . $image . "' data-imagelightbox='f'>
                                                <img style='visibility:hidden;' src='" . $image . "' alt='" . wp_unslash($image_alts[$key]) . "' title='" . wp_unslash($image_titles[$key]) . "' 
                                                 data-description='" . wp_unslash($image_descs[$key]) . "' data-url='" . $image_urls[$key] . "'/>
                                            </a>
                                            <div class='ays_hover_mask'><i class='fa  fa-search-plus'></i></div>
                                        </div>";
                }
                $gallery_view .= "</div>";
                break;/*
                $gallery_view .= "<div class='ays_grid_row'>";
                foreach ($images as $key => $image){
                    $gallery_view .="<div class='ays_grid_column' style='width: ".($column_width - 1)."%; background-image: url(".$image.")'>
                                            <a href='" . $image . "' data-imagelightbox='f'>
                                                <img style='visibility:hidden;' src='" . $image . "' alt='" . wp_unslash($image_alts[$key]) . "' title='" . wp_unslash($image_titles[$key]) . "' 
                                                 data-description='" . wp_unslash($image_descs[$key]) . "' data-url='" . $image_urls[$key] . "'/>
                                            </a>
                                            <div class='ays_hover_mask'><i class='fa  fa-search-plus'></i></div>
                                        </div>";
                }
                $gallery_view .= "</div>";
                break;*/
        }
        $gallery_view .= "</div>";
        return $gallery_view;
    }

    public function ays_get_gallery_by_id( $id ) {
	    global $wpdb;

	    $sql = "SELECT * FROM {$wpdb->prefix}ays_gallery WHERE id={$id}";

	    $result = $wpdb->get_row( $sql, "ARRAY_A" );

	    return $result;
    }

    private function array_split($array, $pieces) {
        if ($pieces < 2)
            return array($array);
        $newCount = ceil(count($array)/$pieces);
        $a = array_slice($array, 0, $newCount);
        $b = $this->array_split(array_slice($array, $newCount), $pieces-1);
        return array_merge(array($a),$b);
    }
}
