(function ($) {
    'use strict';

    let
        // ACTIVITY INDICATOR

        activityIndicatorOn = function () {
            $('<div class="imagelightbox-loading"><div></div></div>').appendTo('body');
        },
        activityIndicatorOff = function () {
            $('.imagelightbox-loading').remove();
        },

        // OVERLAY

        overlayOn = function () {
            $('<div class="imagelightbox-overlay"></div>').appendTo('body');
        },
        overlayOff = function () {
            $('.imagelightbox-overlay').remove();
        },

        // CLOSE BUTTON

        closeButtonOn = function (instance) {
            $('<button type="button" class="imagelightbox-close" title="Close"></button>').appendTo('body').on('click touchend', function () {
                $(this).remove();
                instance.quitImageLightbox();
                return false;
            });
        },
        closeButtonOff = function () {
            $('.imagelightbox-close').remove();
        },

        // CAPTION

        captionOn = function () {
            let ays_title = $('a[href="' + $('.imagelightbox').attr('src') + '"] img').attr('title');
            let ays_desc = $('a[href="' + $('.imagelightbox').attr('src') + '"] img').attr('data-description');
            let ays_url = $('a[href="' + $('.imagelightbox').attr('src') + '"] img').attr('data-url');
            if (ays_title.length > 0)
                $('<div class="imagelightbox-caption"><a class="ays_gallery_caption_link" target="_blank" href="' + ays_url + '">' + ays_title + " <br/> " + ays_desc + '</a></div>').appendTo('body');
        },
        captionOff = function () {
            $('.imagelightbox-caption').remove();
        },

        // NAVIGATION

        navigationOn = function (instance, selector) {
            let images = $(selector);
            if (images.length) {
                let nav = $('<div class="imagelightbox-nav"></div>');
                for (let i = 0; i < images.length; i++)
                    nav.append('<button type="button"></button>');

                nav.appendTo('body');
                nav.on('click touchend', function () {
                    return false;
                });

                let navItems = nav.find('button');
                navItems.on('click touchend', function () {
                    let $this = $(this);
                    if (images.eq($this.index()).attr('href') != $('.imagelightbox').attr('src'))
                        instance.switchImageLightbox($this.index());

                    navItems.removeClass('active');
                    navItems.eq($this.index()).addClass('active');

                    return false;
                })
                    .on('touchend', function () {
                        return false;
                    });
            }
        },
        navigationUpdate = function (selector) {
            let items = $('.imagelightbox-nav button');
            items.removeClass('active');
            items.eq($(selector).filter('[href="' + $('.imagelightbox').attr('src') + '"]').index(selector)).addClass('active');
        },
        navigationOff = function () {
            $('.imagelightbox-nav').remove();
        },

        // ARROWS

        arrowsOn = function (instance, selector) {
            let $arrows = $('<button type="button" class="imagelightbox-arrow imagelightbox-arrow-left"></button><button type="button" class="imagelightbox-arrow imagelightbox-arrow-right"></button>');

            $arrows.appendTo('body');

            $arrows.on('click touchend', function (e) {
                e.preventDefault();

                let $this = $(this),
                    $target = $(selector + '[href="' + $('.imagelightbox').attr('src') + '"]'),
                    index = $target.index(selector);

                if ($this.hasClass('imagelightbox-arrow-left')) {
                    index = index - 1;
                    if (!$(selector).eq(index).length)
                        index = $(selector).length;
                } else {
                    index = index + 1;
                    if (!$(selector).eq(index).length)
                        index = 0;
                }

                instance.switchImageLightbox(index);
                return false;
            });
        },
        arrowsOff = function () {
            $('.imagelightbox-arrow').remove();
        };

    //  WITH ACTIVITY INDICATION

    $('a[data-imagelightbox="a"]').imageLightbox({
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            activityIndicatorOff();
        },
        onEnd: function () {
            activityIndicatorOff();
        }
    });

    //  WITH OVERLAY & ACTIVITY INDICATION

    $('a[data-imagelightbox="b"]').imageLightbox({
        onStart: function () {
            overlayOn();
        },
        onEnd: function () {
            overlayOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            activityIndicatorOff();
        }
    });

    //  WITH "CLOSE" BUTTON & ACTIVITY INDICATION

    let instanceC = $('a[data-imagelightbox="c"]').imageLightbox({
        quitOnDocClick: false,
        onStart: function () {
            closeButtonOn(instanceC);
        },
        onEnd: function () {
            closeButtonOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            activityIndicatorOff();
        }
    });

    //  WITH CAPTION & ACTIVITY INDICATION

    $('a[data-imagelightbox="d"]').imageLightbox({
        onLoadStart: function () {
            captionOff();
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            captionOn();
            activityIndicatorOff();
        },
        onEnd: function () {
            captionOff();
            activityIndicatorOff();
        }
    });

    //  WITH ARROWS & ACTIVITY INDICATION

    let selectorG = 'a[data-imagelightbox="g"]';
    let instanceG = $(selectorG).imageLightbox({
        onStart: function () {
            arrowsOn(instanceG, selectorG);
        },
        onEnd: function () {
            arrowsOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            $('.imagelightbox-arrow').css('display', 'block');
            activityIndicatorOff();
        }
    });

    //  WITH NAVIGATION & ACTIVITY INDICATION

    let selectorE = 'a[data-imagelightbox="e"]';
    let instanceE = $(selectorE).imageLightbox({
        onStart: function () {
            navigationOn(instanceE, selectorE);
        },
        onEnd: function () {
            navigationOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            navigationUpdate(selectorE);
            activityIndicatorOff();
        }
    });

    //  ALL COMBINED

    let selectorF = 'a[data-imagelightbox="f"]';
    let instanceF = $(selectorF).imageLightbox({
        onStart: function () {
            overlayOn();
            closeButtonOn(instanceF);
            arrowsOn(instanceF, selectorF);
        },
        onEnd: function () {
            overlayOff();
            captionOff();
            closeButtonOff();
            arrowsOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            captionOff();
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            captionOn();
            activityIndicatorOff();
            $('.imagelightbox-arrow').css('display', 'block');
        }
    });

    //  DYNAMICALLY ADDED ITEMS

    let instanceH = $('a[data-imagelightbox="h"]').imageLightbox({
        quitOnDocClick: false,
        onStart: function () {
            closeButtonOn(instanceH);
        },
        onEnd: function () {
            closeButtonOff();
            activityIndicatorOff();
        },
        onLoadStart: function () {
            activityIndicatorOn();
        },
        onLoadEnd: function () {
            activityIndicatorOff();
        }
    });

    $('.js--add-dynamic ').on('click', function (e) {
        e.preventDefault();
        let items = $('.js--dynamic-items');
        instanceH.addToImageLightbox(items.find('a'));
        $('.js--dynamic-place').append(items.find('li').detach());
        $(this).remove();
        items.remove();
    });

})(jQuery);